![GitHub tag (latest by date)](https://img.shields.io/github/v/tag/tandav/extraredis)

# extraredis

Extra helper functions for python redis library. Containts both sync and async versions.

## install
### install from [pypi](https://pypi.org/project/extraredis/)
```sh
pip install extraredis
```

### development
```sh
pip install -e .[dev]
```
